pyxmpp2.sasl.plain.PlainServerAuthenticator

Package pyxmpp2 :: Package sasl :: Module plain :: Class PlainServerAuthenticator |
[hide private]

# Class PlainServerAuthenticator

Provides PLAIN SASL authentication for a server.

Nested Classes | [hide private]
Inherited from `core.ServerAuthenticator`: `__metaclass__`

Instance Methods | [hide private]
__init__(self, password_manager) Initialize a PlainServerAuthenticator object. |
sasl.Challenge, sasl.Success or sasl.Failure |
start(self, response) Start the authentication process. |
sasl.Challenge, sasl.Success or sasl.Failure |
response(self, response) Process a client reponse. |
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| _abc_cache = `<_weakrefset.WeakSet object at 0x87906ec>`
| _pyxmpp_sasl_preference = `50`
| _pyxmpp_sasl_secure = `10`
Inherited from `core.ServerAuthenticator`: `__abstractmethods__` Inherited from `core.ServerAuthenticator` (private): `_abc_negative_cache`, `_abc_negative_cache_version`, `_abc_registry`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, password_manager) (Constructor) |
Initialize a PlainServerAuthenticator object. Parameters: `password_manager` (PasswordManager) - name of the password manager object providing authentication credential verification. Overrides: object.__init__

### start(self, response) |
Start the authentication process. Parameters: `response` (`str`) - the initial response from the client. Returns: sasl.Challenge, sasl.Success or sasl.Failure a challenge, a success indicator or a failure indicator. Overrides: core.ServerAuthenticator.start

### response(self, response) |
Process a client reponse. Parameters: `response` (`bytes`) - the response from the client. Returns: sasl.Challenge, sasl.Success or sasl.Failure a challenge, a success indicator or a failure indicator. Overrides: core.ServerAuthenticator.response